django-require-license
======================

Django_ staticfiles post-processor that allows you to prepend a license header to the
compressed file(s) generated by `django-require`_.

.. image:: https://img.shields.io/pypi/v/django-require-license.svg
    :target: https://pypi.python.org/pypi/django-require-license
.. image:: https://travis-ci.org/collab-project/django-require-license.svg?branch=master
    :target: https://travis-ci.org/collab-project/django-require-license
.. image:: https://coveralls.io/repos/collab-project/django-require-license/badge.svg
    :target: https://coveralls.io/r/collab-project/django-require-license
.. image:: https://img.shields.io/badge/license-MIT-blue.svg
    :target: https://raw.githubusercontent.com/collab-project/django-require-license/master/LICENSE


Installation
------------

Use pip_ to download and install the package from PyPi_::

  pip install django-require-license

Or checkout the source code from Github_::

  git clone https://github.com/collab-project/django-require-license.git


Tutorial
--------

Read the :doc:`tutorial` for more information on how to configure
your `django-require`_ and `Require.js`_ project.

.. toctree::
   :maxdepth: 2

   tutorial
   development

.. _Django: https://www.djangoproject.com
.. _pip: https://pypi.python.org/pypi/pip
.. _PyPi: https://pypi.python.org/pypi/django-require-license
.. _Require.js: http://requirejs.org
.. _Github: https://github.com/collab-project/django-require-license
.. _django-require: http://github.com/etianen/django-require
